# GetXlsxTestPointsByTestPlanModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**include_name** | **bool** |  | [optional] 
**include_section** | **bool** |  | [optional] 
**include_priority** | **bool** |  | [optional] 
**include_automated** | **bool** |  | [optional] 
**include_status** | **bool** |  | [optional] 
**include_duration** | **bool** |  | [optional] 
**include_creation_date** | **bool** |  | [optional] 
**include_author** | **bool** |  | [optional] 
**include_modification_date** | **bool** |  | [optional] 
**include_modified_by** | **bool** |  | [optional] 
**include_tags** | **bool** |  | [optional] 
**include_iterations** | **bool** |  | [optional] 
**custom_attributes_ids** | **[str], none_type** |  | [optional] 
**configuration_ids** | **[str], none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


